@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.app.smartbanner.smartbanner package
 
-$Id: interfaces.py 51701 2008-09-13 22:47:48Z cray $
+$Id: interfaces.py 51936 2008-10-23 08:14:17Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51701 $"
+__version__ = "$Revision: 51936 $"
 
 
 from zope.interface import Interface
@@ -56,13 +56,19 @@ class ISmartBannerData(Interface) :
     begin_time = FloatDayTime(
         title = u"Start time",
         description = u"Start time",
-        required = False
+        required = False,
+        min=u'00:00',
+        max=u'24:00',
+        default=u'00:00'
         )
 
     end_time = FloatDayTime(
         title = u"End time",
         description = u"End time",
-        required = False
+        required = False,
+        min=u'00:00',
+        max=u'24:00',
+        default=u'24:00'
         )
 
     rate = Int(
@@ -111,3 +117,8 @@ class ISmartBannerContained(IContained) :
     """ ISmartBanerContained interface
     """
     __parent__ = Field(constraint = ContainerTypesConstraint(ISmartBannerContainer))
+
+
+class ISmartBannerDumb(Interface) :
+    """ Empty Banner """
+    
\ No newline at end of file
