@@ -3,11 +3,11 @@
 """Algortihms Used to select current banner for the
 Zope 3 based ng.app.smartbanner package
 
-$Id: smartbanneralgorithm.py 51701 2008-09-13 22:47:48Z cray $
+$Id: smartbanneralgorithm.py 51936 2008-10-23 08:14:17Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51701 $"
+__version__ = "$Revision: 51936 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
@@ -16,6 +16,7 @@ from zope.component import adapts
 from ng.app.smartbanner.smartbannercontainer.interfaces import ISmartBannerContainer
 from random import shuffle, randint
 from thread import allocate_lock
+from ng.app.smartbanner.smartbanner.smartbannerdumb import SmartBannerDumb
 
 class SmartBannerAlgorithmBase(object) :
 
@@ -39,15 +40,20 @@ class SmartBannerAlgorithmRandom(SmartBannerAlgorithmBase) :
         imgs = []
         sum = 0
         for img in self.values() :
-            imgs.append(img)
-            sum += img.rate
+            if img.filter() :
+                imgs.append(img)
+                sum += img.rate
         
-        rnd = randint(0,sum-1)
-        pos = 0
-        for img in imgs :
-            pos += img.rate 
-            if pos > rnd :
-                break
+        if imgs :
+            rnd = randint(0,sum-1)
+            pos = 0
+            for img in imgs :
+                pos += img.rate 
+                if pos > rnd :
+                    break
+        else :
+            img = SmartBannerDumb()
+            
         return img
 
 class SmartBannerAlgorithmRound(SmartBannerAlgorithmBase) :
@@ -67,7 +73,13 @@ class SmartBannerAlgorithmRound(SmartBannerAlgorithmBase) :
                     break
                 except IndexError :
                     for img in self.values() :
-                        self.queue.extend([img] * int(img.rate))
+                        if img.filter() :
+                            self.queue.extend([img] * int(img.rate))
+
+                    if not self.queue :
+                        img = SmartBannerDumb()
+                        break
+                        
                     shuffle(self.queue)
         finally :                        
             self.lock.release()
