@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 51701 2008-09-13 22:47:48Z cray $
+$Id: interfaces.py 51936 2008-10-23 08:14:17Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 51701 $"
+__version__ = "$Revision: 51936 $"
  
 from zope.interface import Interface
 
@@ -38,7 +38,7 @@ class ISmartBannerContainerData(Interface) :
         default = 'Random',
     )
 
-class ISmartBannerContainer ( IOrderedContainer ) :
+class ISmartBannerContainer ( IOrderedContainer, ISmartBannerContainerData ) :
     """ """
     def __setitem__(name, object) :
         """ Add a ISmartBannerContent object. """
